@@ -22,10 +22,14 @@ from mycli.packages.special.favoritequeries import FavoriteQueries
 from mycli.packages.special.main import ArgType, special_command
 from mycli.packages.special.utils import handle_cd_command
 
+sqlparse.engine.grouping.MAX_GROUPING_DEPTH = None  # type: ignore[assignment]
+sqlparse.engine.grouping.MAX_GROUPING_TOKENS = None  # type: ignore[assignment]
+
 TIMING_ENABLED = False
 use_expanded_output = False
 force_horizontal_output = False
 PAGER_ENABLED = True
+SHOW_FAVORITE_QUERY = True
 tee_file = None
 once_file = None
 written_to_once_file = False
@@ -58,6 +62,15 @@ def is_pager_enabled() -> bool:
     return PAGER_ENABLED
 
 
+def set_show_favorite_query(val: bool) -> None:
+    global SHOW_FAVORITE_QUERY
+    SHOW_FAVORITE_QUERY = val
+
+
+def is_show_favorite_query() -> bool:
+    return SHOW_FAVORITE_QUERY
+
+
 @special_command(
     "pager",
     "\\P [command]",
@@ -255,12 +268,12 @@ def execute_favorite_query(cur: Cursor, arg: str, **_) -> Generator[tuple, None,
         yield (None, None, None, message)
     else:
         query, arg_error = subst_favorite_query_args(query, args)
-        if arg_error:
+        if query is None:
             yield (None, None, None, arg_error)
         else:
             for sql in sqlparse.split(query):
                 sql = sql.rstrip(";")
-                title = f"> {sql}"
+                title = f"> {sql}" if is_show_favorite_query() else None
                 cur.execute(sql)
                 if cur.description:
                     headers = [x[0] for x in cur.description]
@@ -380,7 +393,7 @@ def set_tee(arg: str, **_) -> list[tuple]:
     try:
         tee_file = open(*parseargfile(arg))
     except (IOError, OSError) as e:
-        raise OSError(f"Cannot write to file '{e.filename}': {e.strerror}")
+        raise OSError(f"Cannot write to file '{e.filename}': {e.strerror}") from e
 
     return [(None, None, None, "")]
 
@@ -413,7 +426,7 @@ def set_once(arg: str, **_) -> list[tuple]:
     try:
         once_file = open(*parseargfile(arg))
     except (IOError, OSError) as e:
-        raise OSError(f"Cannot write to file '{e.filename}': {e.strerror}")
+        raise OSError(f"Cannot write to file '{e.filename}': {e.strerror}") from e
     written_to_once_file = False
 
     return [(None, None, None, "")]
@@ -456,7 +469,7 @@ def _run_post_redirect_hook(post_redirect_command: str, filename: str) -> None:
             stderr=subprocess.DEVNULL,
         )
     except Exception as e:
-        raise OSError(f"Redirect post hook failed: {e}")
+        raise OSError(f"Redirect post hook failed: {e}") from e
 
 
 @special_command("\\pipe_once", "\\| command", "Send next result to a subprocess.", aliases=["\\|"])
