@@ -1,12 +1,15 @@
+# type: ignore
+
 import pytest
+
 from mycli.packages.parseutils import (
     extract_tables,
     extract_tables_from_complete_statements,
-    query_starts_with,
-    queries_start_with,
     is_destructive,
-    query_has_where_clause,
     is_dropping_database,
+    queries_start_with,
+    query_has_where_clause,
+    query_starts_with,
 )
 
 
@@ -139,9 +142,9 @@ def test_query_starts_with_comment():
 
 def test_queries_start_with():
     sql = "# comment\nshow databases;use foo;"
-    assert queries_start_with(sql, ("show", "select")) is True
-    assert queries_start_with(sql, ("use", "drop")) is True
-    assert queries_start_with(sql, ("delete", "update")) is False
+    assert queries_start_with(sql, ["show", "select"]) is True
+    assert queries_start_with(sql, ["use", "drop"]) is True
+    assert queries_start_with(sql, ["delete", "update"]) is False
 
 
 def test_is_destructive():
